#!/bin/bash
emoncms_var="/var/opt/emoncms"
emoncms_root="/var/www/emoncms"
emoncms_user="www-data"

if test -f $passwd_file && grep -Fxq "[MySQL]" $passwd_file; then
    if grep -A3 -P '^\[MySQL\]$' $passwd_file | grep -m1 -q "emoncms" $passwd_file; then
	    mysql_user="emoncms"
	else
	    mysql_user="root"
	fi
	mysql_pwd=$(grep -A3 -P "^\[MySQL\]$" $passwd_file | grep -m1 "$mysql_user:" | sed "s/$mysql_user://g")
else
    mysql_user="root"
    mysql_pwd=""
fi
if [ -f $conf_dir/backup.d/emoncms.conf ]; then
    source "$conf_dir/backup.d/emoncms.conf"
fi

export_backup() {
    # Make sure the rsync file does not exist yet
    rm -rf $rsync_file > /dev/null 2>&1

    # Export emoncms settings
    if [ -f $emoncms_root/settings.ini ]; then
        echo "$emoncms_root/settings.ini" >> $tmp_dir/emoncms-rsync.txt
    fi

    # Export emoncms variable data
    if [ -d $emoncms_var/mysql ]; then
        echo "$emoncms_var/mysql" >> $tmp_dir/emoncms-rsync.txt
    fi
    if [ -d $emoncms_var/phpfina ]; then
        echo "$emoncms_var/phpfina" >> $tmp_dir/emoncms-rsync.txt
    fi
    if [ -d $emoncms_var/phptimeseries ]; then
        echo "$emoncms_var/phptimeseries" >> $tmp_dir/emoncms-rsync.txt
    fi

    # Export emoncms MySQL user dump
    if mysql      --user="$mysql_user" --password="$mysql_pwd" -e "USE emoncms" > /dev/null 2>&1; then
        mysqldump --user="$mysql_user" --password="$mysql_pwd"         emoncms  > $tmp_dir/emoncms.sql
        echo "$tmp_dir/emoncms.sql"                                            >> $tmp_dir/emoncms-rsync.txt
    fi
    if mysql      --user="$mysql_user" --password="$mysql_pwd" -e "USE emondata" > /dev/null 2>&1; then
        mysqldump --user="$mysql_user" --password="$mysql_pwd"         emondata > $tmp_dir/emondata.sql
        echo "$tmp_dir/emondata.sql"                                           >> $tmp_dir/emoncms-rsync.txt
    fi

    if [ -s "$tmp_dir/emoncms-rsync.txt" ]; then
        ssh -i $seal_dir/rsa_key $remote_user@$remote_host "mkdir -p $remote_dir/emoncms"

        # Sync emoncms settings, SQL dump and timeseries
        rsync -rulDtz --rsh="ssh -i $seal_dir/rsa_key" \
                      --files-from="$tmp_dir/emoncms-rsync.txt" \
                      --no-relative / $remote_user@$remote_host:$remote_dir/emoncms
    fi
}

import_backup() {
    chown $emoncms_user:$emoncms_user -R $tmp_dir/emoncms

    # Import emoncms settings
    if [ -f $tmp_dir/emoncms/settings.ini ]; then
        cp -pf $tmp_dir/emoncms/settings.ini $emoncms_root/settings.ini

    elif [ -f $tmp_dir/emoncms/settings.php ]; then
        cp -pf $tmp_dir/emoncms/settings.php $emoncms_root/settings.php
    fi

    # Import emoncms variable data
    mkdir -p $emoncms_var
    chown $emoncms_user:$emoncms_user -R $emoncms_var

    if [ -d $tmp_dir/emoncms/mysql ]; then
        mkdir -p $emoncms_var/mysql
        cp -pf $tmp_dir/emoncms/mysql/* $emoncms_var/mysql/
    fi
    if [ -d $tmp_dir/emoncms/phpfina ]; then
        mkdir -p $emoncms_var/phpfina
        cp -pf $tmp_dir/emoncms/phpfina/* $emoncms_var/phpfina/
    fi
    if [ -d $tmp_dir/emoncms/phptimeseries ]; then
        mkdir -p $emoncms_var/phptimeseries
        cp -pf $tmp_dir/emoncms/phptimeseries/* $emoncms_var/phptimeseries/
    fi

    # Import emoncms MySQL user dump
    if [ -e $tmp_dir/emoncms/emoncms.sql ]; then
        mysql --user=$mysql_user --password=$mysql_pwd emoncms < $tmp_dir/emoncms/emoncms.sql
    fi
    if [ -e $tmp_dir/emoncms/emondata.sql ]; then
        mysql --user=$mysql_user --password=$mysql_pwd emondata < $tmp_dir/emoncms/emondata.sql
    fi
	redis-cli FLUSHALL
}
