#!/bin/bash
openmuc_var="/var/opt/openmuc"
openmuc_root="/opt/openmuc"
openmuc_user="muc"

if test -f $passwd_file && grep -Fxq "[MySQL]" $passwd_file; then
    if grep -A3 -P '^\[MySQL\]$' $passwd_file | grep -m1 -q "openmuc" $passwd_file; then
	    mysql_user="openmuc"
	else
	    mysql_user="root"
	fi
	mysql_pwd=$(grep -A3 -P "^\[MySQL\]$" $passwd_file | grep -m1 "$mysql_user:" | sed "s/$mysql_user://g")
else
    mysql_user="root"
    mysql_pwd=""
fi
if [ -f $conf_dir/backup.d/openmuc.conf ]; then
    source "$conf_dir/backup.d/openmuc.conf"
fi

export_backup() {
    # Make sure the rsync file does not exist yet
    rm -rf $rsync_file > /dev/null 2>&1

    # Export OpenMUC configurations
    if [ -d $openmuc_root/conf ]; then
        echo "$openmuc_root/conf" >> $tmp_dir/openmuc-rsync.txt
    fi

    # Export OpenMUC variable data
    if [ -d $openmuc_var ]; then
        echo "$openmuc_var/channels.xml" >> $tmp_dir/openmuc-rsync.txt
        echo "$openmuc_var/install"      >> $tmp_dir/openmuc-rsync.txt
    fi

    # Export OpenMUC MySQL user dump
    if mysql      --user="$mysql_user" --password="$mysql_pwd" -e "USE openmuc" > /dev/null 2>&1; then
        mysqldump --user="$mysql_user" --password="$mysql_pwd"         openmuc  > $tmp_dir/openmuc.sql
        echo "$tmp_dir/openmuc.sql"                                            >> $tmp_dir/openmuc-rsync.txt
    fi

    if [ -s "$tmp_dir/openmuc-rsync.txt" ]; then
        ssh -i $seal_dir/rsa_key $remote_user@$remote_host "mkdir -p $remote_dir/openmuc"

        # Sync OpenMUC settings, SQL dump and timeseries
        rsync -rulDtz --rsh="ssh -i $seal_dir/rsa_key" \
                      --files-from="$tmp_dir/openmuc-rsync.txt" \
                      --no-relative / $remote_user@$remote_host:$remote_dir/openmuc
    fi
}

import_backup() {
    chown $openmuc_user:$openmuc_user -R $tmp_dir/openmuc

    # Import OpenMUC configurations
    if [ -d $tmp_dir/openmuc/conf ]; then
        cp -rpf $tmp_dir/openmuc/conf $openmuc_root
    fi

    # Import OpenMUC variable data
    mkdir -p $openmuc_var
    chown $openmuc_user:$openmuc_user -R $openmuc_var

    if [ -f $tmp_dir/openmuc/channels.xml ]; then
        cp -pf $tmp_dir/openmuc/channels.xml $openmuc_var
    fi
    if [ -d $tmp_dir/openmuc/install ]; then
        mkdir -p $openmuc_var/install
        cp -rpf $tmp_dir/openmuc/install $openmuc_var
    fi

    # Import OpenMUC MySQL user dump
    if [ -e $tmp_dir/openmuc/openmuc.sql ]; then
        mysql --user=$mysql_user --password=$mysql_pwd openmuc < $tmp_dir/openmuc/openmuc.sql
    fi
}
