#!/bin/bash
usr="pi"
usr_dir="/home/$usr"
tmp_dir="/var/lib/seal/backup"
conf_dir="/etc/seal"
root_dir="/usr/lib/seal"
seal_dir="/usr/local/lib/seal"
setup_dir="$usr_dir/.setup"
passwd_file="$setup_dir/passwd.conf"

if [ "$(id -u)" != 0 ]; then
    echo 1>&2 "This script requires root access"
    exit 1
fi

export_seal() {
    ssh -i $seal_dir/rsa_key $remote_user@$remote_host "mkdir -p $remote_dir/setup"

    # Sync seal setup directory
    rsync -ruDtz --rsh="ssh -i $seal_dir/rsa_key" $setup_dir/* $remote_user@$remote_host:$remote_dir/setup

    for source_file in $root_dir/backup.d/*.sh; do
        source $source_file
        export_backup
    done
}

import_seal() {
    rsync -rlDtz --rsh="ssh -i $seal_dir/rsa_key" $remote_user@$remote_host:$remote_dir/* $tmp_dir

    # Export seal setup directory
    if [ -d $tmp_dir/setup ]; then
        cp -pf $tmp_dir/setup/* $setup_dir
    fi
    chown pi:pi -R $setup_dir

    for import_file in $root_dir/backup.d/*.sh; do
        source $import_file
        import_backup
    done
}

mkdir -p $tmp_dir

source "$conf_dir/backup.conf"
case "$1" in
    "import")
        import_seal
        ;;
    "export")
        export_seal
        ;;
    *)
        echo "Synopsis: backup {import|export}"
        exit 1
        ;;
esac
rm -rf $tmp_dir > /dev/null 2>&1

exit 0
